@@ -776,7 +776,7 @@ class ArithmeticExpression(LeftOperatorRightExpressionBase):
 	_op_tdiv = functools.partialmethod(__op_arithmetic, operator.truediv)
 	_op_mod  = functools.partialmethod(__op_arithmetic, operator.mod)
 	_op_mul  = functools.partialmethod(__op_arithmetic, operator.mul)
-	_op_pow  = functools.partialmethod(__op_arithmetic, math.pow)
+	_op_pow  = functools.partialmethod(__op_arithmetic, operator.pow)
 
 class BitwiseExpression(LeftOperatorRightExpressionBase):
 	"""
@@ -847,8 +847,6 @@ class LogicExpression(LeftOperatorRightExpressionBase):
 class ComparisonExpression(LeftOperatorRightExpressionBase):
 	"""A class for representing comparison expressions from the grammar text such as equality checks."""
 	def _op_eq(self, thing):
-		if not DataType.is_compatible(self.left.result_type, self.right.result_type):
-			return False
 		left_value = self.left.evaluate(thing)
 		right_value = self.right.evaluate(thing)
 		if type(left_value) is not type(right_value):
@@ -856,8 +854,6 @@ class ComparisonExpression(LeftOperatorRightExpressionBase):
 		return operator.eq(left_value, right_value)
 
 	def _op_ne(self, thing):
-		if not DataType.is_compatible(self.left.result_type, self.right.result_type):
-			return True
 		left_value = self.left.evaluate(thing)
 		right_value = self.right.evaluate(thing)
 		if type(left_value) is not type(right_value):
@@ -1004,7 +1000,13 @@ class GetAttributeExpression(ExpressionBase):
 		self.object = object_
 		if self.object.result_type != DataType.UNDEFINED:
 			if not (self.object.result_type == DataType.NULL and safe):
-				self.result_type = context.resolve_attribute_type(self.object.result_type, name)
+				try:
+					self.result_type = context.resolve_attribute_type(self.object.result_type, name)
+				except errors.AttributeResolutionError as error:
+					# this is necessary because MAPPING objects can have their keys accessed as attributes
+					if not isinstance(self.object.result_type, DataType.MAPPING.__class__):
+						raise error
+					# leave the result type undefined because the name could be a mapping key or attribute
 		self.name = name
 		self.safe = safe
 
